@@ -9,6 +9,13 @@ class MappingError(object):
     def __repr__(self):
         return "{}".format(self.message)
 
+    def __eq__(self, other):
+        return (
+            isinstance(other, MappingError)
+            and self.type == other.type
+            and self.message == other.message
+        )
+
 
 class PropertiesError(MappingError):
     def __init__(self, message):
@@ -30,3 +37,9 @@ class PathError(MappingError):
 class FieldError(MappingError):
     def __init__(self, message):
         super(FieldError, self).__init__(message, "Field")
+
+
+class FieldSyntaxError(MappingError):
+    def __init__(self, field):
+        message = "Required field [{}] not found".format(field)
+        super(FieldSyntaxError, self).__init__(message, "FieldSyntaxError")
